@@ -1,12 +1,15 @@
 """Pylons environment configuration"""
 import os
 
+from mako.lookup import TemplateLookup
 from pylons import config
+from pylons.error import handle_mako_error
 from sqlalchemy import engine_from_config
 
 import quickwiki.lib.app_globals as app_globals
 import quickwiki.lib.helpers
 from quickwiki.config.routing import make_map
+from quickwiki.model import init_model
 
 def load_environment(global_conf, app_conf):
     """Configure the Pylons environment via the ``pylons.config``
@@ -20,17 +23,23 @@ def load_environment(global_conf, app_conf):
                  templates=[os.path.join(root, 'templates')])
 
     # Initialize config with the basic options
-    config.init_app(global_conf, app_conf, package='quickwiki',
-                    template_engine='mako', paths=paths)
+    config.init_app(global_conf, app_conf, package='quickwiki', paths=paths)
 
     config['routes.map'] = make_map()
-    config['pylons.g'] = app_globals.Globals()
+    config['pylons.app_globals'] = app_globals.Globals()
     config['pylons.h'] = quickwiki.lib.helpers
 
-    # Customize templating options via this variable
-    tmpl_options = config['buffet.template_options']
+    # Create the Mako TemplateLookup, with the default auto-escaping
+    config['pylons.app_globals'].mako_lookup = TemplateLookup(
+        directories=paths['templates'],
+        error_handler=handle_mako_error,
+        module_directory=os.path.join(app_conf['cache_dir'], 'templates'),
+        input_encoding='utf-8', default_filters=['escape'],
+        imports=['from webhelpers.html import escape'])
+
+    # Setup the SQLAlchemy database engine
+    engine = engine_from_config(config, 'sqlalchemy.')
+    init_model(engine)
 
     # CONFIGURATION OPTIONS HERE (note: all config options will override
     # any Pylons config options)
-    config['pylons.g'].sa_engine = engine_from_config(config,
-                                                      'sqlalchemy.default.')
